ServerException class

Exception occurring when network fails or parsed response is missing both data and errors

Inheritance
Annotations
  • @immutable

Constructors

ServerException({Response? parsedResponse, int? statusCode, Object? originalException, StackTrace? originalStackTrace})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
originalException → Object?
The original exception causing this exception
finalinherited
originalStackTrace → StackTrace?
finalinherited
parsedResponse → Response?
The parsed response
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int?
The status code of the request, if available
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited